---
title: About Grouping Content
weight: 100
---
# Grouping content in a folder

You can group related content into subfolders.

## Nav Menu

The Nav Menu on the left allows you to reorganize content as needed.  If you hover over any item in the nav menu you'll see settings and arrows appear.  Arrows are for moving documentation arround.  :arrow_forward: right arrow (i.e. indent) will create a subfolder or move the document into a subfolder.  If you hold SHIFT+:arrow_forward: then it will always create a subfolder.

## Automatic content refactoring

Reorganizing the content with the Nav Menu will automatically refactor the contents of all related documentation.  For example, moving a document into a sub-folder will automatically fix other documents which link to it.
